@@ -2,7 +2,7 @@
  * This is GNU GO, a Go program. Contact gnugo@gnu.org, or see   *
  * http://www.gnu.org/software/gnugo/ for more information.      *
  *                                                               *
- * Copyright 1999 and 2000 by the Free Software Foundation.      *
+ * Copyright 1999, 2000, 2001 by the Free Software Foundation.   *
  *                                                               *
  * This program is free software; you can redistribute it and/or *
  * modify it under the terms of the GNU General Public License   *
@@ -17,7 +17,7 @@
  * You should have received a copy of the GNU General Public     *
  * License along with this program; if not, write to the Free    *
  * Software Foundation, Inc., 59 Temple Place - Suite 330,       *
- * Boston, MA 02111, USA                                         *
+ * Boston, MA 02111, USA.                                        *
 \* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 
@@ -35,6 +35,11 @@ struct eye_vertex {
   int n2;                         /* second neighbor                       */
   int n3;                         /* third neighbor                        */
   int n4;                         /* fourth neighbor                       */
+  int edge;                       /* 0=center, 1=edge, 2=corner            */
+  /* A corner vertex may only be matched at the corner.
+   * An edge vertex may be matched at the corner or on the edge.
+   * A center vertex may be matched anywhere.
+   */
 };
 
 
@@ -53,9 +58,12 @@ struct eye_graph {
   int three_neighbors;            /* number of vertices with 3 neighbors   */
   int max;                        /* number of eyes if O plays first       */
   int min;                        /* number of eyes if X plays first       */
-  int vital;                      /* vital point (only if max != min)      */
+  int vital;                      /* 1st attack and defense vital point    */
+				  /* (only if max != min)  */
+  int num_vital;                  /* number of vital points                */
 };
 
+extern struct eye_graph graphs[];
 
 /*
  * Local Variables:
