@@ -2,7 +2,7 @@
  * This is GNU GO, a Go program. Contact gnugo@gnu.org, or see   *
  * http://www.gnu.org/software/gnugo/ for more information.      *
  *                                                               *
- * Copyright 1999 and 2000 by the Free Software Foundation.      *
+ * Copyright 1999, 2000, 2001 by the Free Software Foundation.   *
  *                                                               *
  * This program is free software; you can redistribute it and/or *
  * modify it under the terms of the GNU General Public License   *
@@ -21,117 +21,98 @@
 \* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 
-
-
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <assert.h>
 #include <ctype.h>
 
-#include "sgf_utils.h"
-#include "ttsgf.h"
-#include "ttsgf_read.h"
-#include "sgf_properties.h"
-
-#include "liberty.h"
-#include "interface.h"
-
-
-/*
- * Convert a 2 character (move) string to its short value.
- * Primarily used for the switch() over the SGF tags.
- */
-
-short
-str2short(char *str)
-{
-  return (str[0] | str[1] << 8);
-}
-
+#include "sgftree.h"
 
 /* 
  * Return the integer X move.
  */
 
 int
-get_moveX(SGFPropertyP property)
+get_moveX(SGFProperty *property, int boardsize)
 {
+  int i;
   if (!property->value[1])
-    return board_size;
+    return -1;
 
-  return toupper(property->value[1]) - 'A';
+  i = toupper((int) property->value[1]) - 'A';
+  if (i >= boardsize)
+    return -1;
+
+  return i;
 }
 
-
 /* 
  * Return the integer Y move.
  */
 
 int
-get_moveY(SGFPropertyP property)
+get_moveY(SGFProperty *property, int boardsize)
 {
+  int j;
   if (!property->value[0])
-    return board_size;
+    return -1;
 
-  return toupper(property->value[0]) - 'A';
+  j = toupper((int) property->value[0]) - 'A';
+  if (j >= boardsize)
+    return -1;
+
+  return j;
 }
 
 
-/*
- * Test if the move is a pass or not.  Return 1 if it is.
+/* Fills (*i, *j) from the property value, in GNU Go co-ords.
+ * Note that GNU Go uses different conventions from sgf for
+ * co-ordinates been called. 
+ *
+ * Returns 1 for a move, 0 for a pass.
  */
 
 int
-is_pass(int i, int j)
+get_moveXY(SGFProperty *property, int *i, int *j, int boardsize)
 {
-  /* check for FF3 style pass: [tt] if boardsize <=19... */
-  if (get_boardsize()<=19)
-    if (i==19 || j==19)
-      return 1;
-
-  /* Use an || here just in case... (should really be &&) */
-  if (i==get_boardsize() || j==get_boardsize())
-    return 1;
-
-  return 0;
+  *i = get_moveX(property, boardsize);
+  *j = get_moveY(property, boardsize);
+  
+  return !is_pass(*i, *j);
 }
 
 
-
 /* 
  * Debugging function to print properties as they are traversed.
  */
 
 int
-show_sgf_properties(SGFNodeP node)
+show_sgf_properties(SGFNode *node)
 {
-  SGFPropertyP sgf_prop;
+  SGFProperty *sgf_prop;
   int propcount;
 
   propcount=0;
 
   printf("P: ");
-  if(!node->prop) {
+  if (!node->props) {
     printf("None\n");
     return propcount;
   }
   else {
-    sgf_prop = node->prop;
+    sgf_prop = node->props;
     while (sgf_prop) {
-      printf("%c%c ",sgf_prop->name & 0x00FF, (sgf_prop->name & 0xFF00)>>8);
-      sgf_prop=sgf_prop->next;
+      printf("%c%c ", sgf_prop->name & 0x00FF, (sgf_prop->name & 0xFF00)>>8);
+      sgf_prop = sgf_prop->next;
       propcount++;
     }
 
-    printf("(%d) ",propcount);
-    if(node->next) printf("n");
-    if(node->child) printf("c");
+    printf("(%d) ", propcount);
+    if (node->next)
+      printf("n");
+    if (node->child)
+      printf("c");
     printf("\n");
   }
 
@@ -144,9 +125,9 @@ show_sgf_properties(SGFNodeP node)
  */
 
 int
-show_sgf_tree(SGFNodeP node)
+show_sgf_tree(SGFNode *node)
 {
-  int n=0; /* number of nodes */
+  int n = 0; /* number of nodes */
   
   n++;
   show_sgf_properties(node);
@@ -167,33 +148,32 @@ show_sgf_tree(SGFNodeP node)
  */
 
 int
-is_markup_node(SGFNodeP node)
+is_markup_node(SGFNode *node)
 {
-  SGFPropertyP sgf_prop;
+  SGFProperty *sgf_prop;
   
   /* If the node has no properties, there's nothing to do.
      This should have been checked by the caller, but it can't hurt. */
-  if(!node->prop)
+  if (!node->props)
     return 0;
-  else {
-    sgf_prop = node->prop;
-    while (sgf_prop) {
-      switch(sgf_prop->name) {
-      case SGFCR : 
-      case SGFSQ : /* Square */
-      case SGFTR : /* Triangle */
-      case SGFMA : /* Mark */
-      case SGFBM : /* bad move */
-      case SGFDO : /* doubtful move */
-      case SGFIT : /* interesting move */
-      case SGFTE : /* good move */
-	return 1;
-	break;
-      default :
-	break;
-      }
-      sgf_prop=sgf_prop->next;
+
+  sgf_prop = node->props;
+  while (sgf_prop) {
+    switch (sgf_prop->name) {
+    case SGFCR: 
+    case SGFSQ: /* Square */
+    case SGFTR: /* Triangle */
+    case SGFMA: /* Mark */
+    case SGFBM: /* bad move */
+    case SGFDO: /* doubtful move */
+    case SGFIT: /* interesting move */
+    case SGFTE: /* good move */
+      return 1;
+      break;
+    default:
+      break;
     }
+    sgf_prop = sgf_prop->next;
   }
 
   /* No markup property found. */
@@ -206,27 +186,58 @@ is_markup_node(SGFNodeP node)
  */
 
 int
-is_move_node(SGFNodeP node)
+is_move_node(SGFNode *node)
 {
-  SGFPropertyP sgf_prop;
+  SGFProperty *sgf_prop;
   
   /* If the node has no properties, there's nothing to do.
      This should have been checked by the caller, but it can't hurt. */
-  if (!node->prop)
+  if (!node->props)
     return 0;
-  else {
-    sgf_prop = node->prop;
-    while (sgf_prop) {
-      switch(sgf_prop->name) {
-      case SGFB : 
-      case SGFW : 
-	return 1;
-	break;
-      default :
-	break;
-      }
-      sgf_prop=sgf_prop->next;
+
+  sgf_prop = node->props;
+  while (sgf_prop) {
+    switch (sgf_prop->name) {
+    case SGFB: 
+    case SGFW: 
+      return 1;
+      break;
+    default:
+      break;
     }
+    sgf_prop = sgf_prop->next;
+  }
+
+  return 0;
+}
+
+
+/*
+ * Determine if the node has a pass move in it.
+ */
+
+int
+is_pass_node(SGFNode *node, int boardsize)
+{
+  SGFProperty *sgf_prop;
+  int i, j;
+  
+  /* If the node has no properties, there's nothing to do.
+     This should have been checked by the caller, but it can't hurt. */
+  if (!node->props)
+    return 0;
+
+  sgf_prop = node->props;
+  while (sgf_prop) {
+    switch (sgf_prop->name) {
+    case SGFB: 
+    case SGFW: 
+      return !get_moveXY(sgf_prop, &i, &j, boardsize);
+      break;
+    default:
+      break;
+    }
+    sgf_prop = sgf_prop->next;
   }
 
   return 0;
@@ -238,66 +249,34 @@ is_move_node(SGFNodeP node)
  */
 
 int
-find_move(SGFNodeP node)
+find_move(SGFNode *node)
 {
-  SGFPropertyP sgf_prop;
+  SGFProperty *sgf_prop;
   
   /* If the node has no properties, there's nothing to do.
      This should have been checked by the caller, but it can't hurt. */
-  if (!node->prop)
+  if (!node->props)
     return 0;
-  else {
-    sgf_prop = node->prop;
-    while (sgf_prop) {
-      switch(sgf_prop->name) {
-      case SGFB : 
-	return BLACK;
-	break;
-      case SGFW : 
-	return WHITE;
-	break;
-      default :
-	break;
-      }
-      sgf_prop=sgf_prop->next;
+
+  sgf_prop = node->props;
+  while (sgf_prop) {
+    switch (sgf_prop->name) {
+    case SGFB: 
+      return BLACK;
+      break;
+    case SGFW: 
+      return WHITE;
+      break;
+    default:
+      break;
     }
+    sgf_prop = sgf_prop->next;
   }
+
   return EMPTY;
 }
 
 
-/*
- * Look for a testmode=... comment in the top node of the sgf file
- * and, if found, return it.
- */
-
-enum testmode
-guess_mode_from_sgf_comment(SGFNodeP sgf)
-{
-  SGFPropertyP prop;
-  for (prop = sgf->prop ; prop ; prop=prop->next) {
-    if (prop->name == SGFC) {
-      /* a comment; Is it  testmode=... ? */
-      if (strncmp(prop->value, "testmode=", 9) != 0)
-	continue;
-
-      /* Yes it was!  Now find out which testmode it is. */
-      if (strncmp(prop->value + 9, "game", 4) == 0)
-	return GAME;
-      if (strncmp(prop->value + 9, "both", 4) == 0)
-	return BOTH;
-      if (strncmp(prop->value + 9, "move", 4) == 0)
-	return MOVE_ONLY;
-      if (strncmp(prop->value + 9, "annotation", 10) == 0)
-	return ANNOTATION_ONLY;
-    }
-  }
-
-  return UNKNOWN_TESTMODE;
-}
-
-
-
 /*
  * Local Variables:
  * tab-width: 8
