@@ -2,7 +2,7 @@
  * This is GNU GO, a Go program. Contact gnugo@gnu.org, or see   *
  * http://www.gnu.org/software/gnugo/ for more information.      *
  *                                                               *
- * Copyright 1999 and 2000 by the Free Software Foundation.      *
+ * Copyright 1999, 2000, 2001 by the Free Software Foundation.   *
  *                                                               *
  * This program is free software; you can redistribute it and/or *
  * modify it under the terms of the GNU General Public License   *
@@ -17,36 +17,21 @@
  * You should have received a copy of the GNU General Public     *
  * License along with this program; if not, write to the Free    *
  * Software Foundation, Inc., 59 Temple Place - Suite 330,       *
- * Boston, MA 02111, USA                                         *
+ * Boston, MA 02111, USA.                                        *
 \* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-
-
-
 /*
  * A little program to convert the SGF Spec into something usable in a
  * parser- basically, the two letters moved into a 'short'
  */
 
-/* This tells Alpha OSF/1 not to define a getopt prototype in <stdio.h>.
- * Ditto for AIX 3.2 and <stdlib.h>.        
- */
-#ifndef _NO_PROTO
-#define _NO_PROTO
-#endif
-
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-#include "../utils/getopt.h"
-
-
 #define MAX_LINE 128
 
-static short str2short(char *);
-
+static short str2short(char *str);
 
 /*
  * combine two characters into a short.
@@ -58,7 +43,6 @@ str2short(char *str)
   return (str[0] | str[1] << 8);
 }
 
-
 int 
 main(void)
 {
@@ -67,36 +51,37 @@ main(void)
   char comment[MAX_LINE];
   int i;
 
-  while(fgets(instring, MAX_LINE, stdin)) {
-    i= strlen(instring)-1;
+  while (fgets(instring, MAX_LINE, stdin)) {
+    i = strlen(instring) - 1;
       
     /* Remove trailing newline and spaces */
-    while(instring[i]== ' ' || instring[i] == 10)
-      instring[i--]=0;
+    while (i >= 0 
+	   && (instring[i] == ' ' || instring[i] == 10))
+      instring[i--] = 0;
       
     /* Blank lines stay blank lines */
-    if(strcmp(instring,"")==0) {
+    if (strcmp(instring, "") == 0) {
       fprintf(stdout, "\n");
       continue;
     }
       
     sscanf(instring, "%4s %75s", sgf_tag, comment);
     strncpy(sgf_tag, instring, 4);
-    if(strlen(instring)>4) 
+    if (strlen(instring) > 4) 
       strncpy(comment, instring+4, MAX_LINE-4);
     else
       strcpy(comment, "");
 
     /* outdated and modified notations. */
     /* just shift everything over */
-    if ((sgf_tag[0]== '*') || (sgf_tag[0]=='!')) {
+    if (sgf_tag[0] == '*' || sgf_tag[0] == '!') {
       sgf_tag[0] = sgf_tag[1];
       sgf_tag[1] = sgf_tag[2];
       sgf_tag[2] = sgf_tag[3];
     }
       
     /* If its not a real tag, just take it as a comment. */
-    if ((sgf_tag[0]<'A') || (sgf_tag[0]>'Z')) {
+    if (sgf_tag[0] < 'A' || sgf_tag[0] > 'Z') {
       fprintf(stdout, "/* %s */\n", instring);
       continue;
     }
