@@ -21,16 +21,13 @@
    write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.  */
 
+
 /* This tells Alpha OSF/1 not to define a getopt prototype in <stdio.h>.
    Ditto for AIX 3.2 and <stdlib.h>.  */
 #ifndef _NO_PROTO
 # define _NO_PROTO
 #endif
 
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
-
 #if !defined __STDC__ || !__STDC__
 /* This is a separate conditional since some stdc systems
    reject `defined (const)'.  */
@@ -53,7 +50,7 @@
 #if !defined _LIBC && defined __GLIBC__ && __GLIBC__ >= 2
 # include <gnu-versions.h>
 # if _GNU_GETOPT_INTERFACE_VERSION == GETOPT_INTERFACE_VERSION
-#  define ELIDE_CODE
+/*#  define ELIDE_CODE*/
 # endif
 #endif
 
@@ -66,16 +63,12 @@
 /* Don't include stdlib.h for non-GNU C libraries because some of them
    contain conflicting prototypes for getopt.  */
 # include <stdlib.h>
-# ifdef HAVE_UNISTD_H
 # include <unistd.h>
-# endif
 #endif	/* GNU C library.  */
 
 #ifdef VMS
 # include <unixlib.h>
-# if HAVE_STRING_H - 0
-#  include <string.h>
-# endif
+# include <string.h>
 #endif
 
 #ifndef _
@@ -103,7 +96,7 @@
    GNU application programs can use a third alternative mode in which
    they can distinguish the relative order of options and other arguments.  */
 
-#include "getopt.h"
+#include "gg-getopt.h"
 
 /* For communication from `getopt' to the caller.
    When `getopt' finds an option that takes an argument,
@@ -126,7 +119,7 @@ char *optarg;
    how much of ARGV has been scanned so far.  */
 
 /* 1003.2 says this must be 1 before any call.  */
-int optind = 1;
+int gg_optind = 1;
 
 /* Formerly, initialization of getopt depended on optind==0, which
    causes problems with re-calling getopt as programs generally don't
@@ -146,13 +139,13 @@ static char *nextchar;
 /* Callers store zero here to inhibit the error message
    for unrecognized options.  */
 
-int opterr = 1;
+int gg_opterr = 1;
 
 /* Set to an option character which was unrecognized.
    This must be initialized on some systems to avoid linking in the
    system's own getopt implementation.  */
 
-int optopt = '?';
+int gg_optopt = '?';
 
 /* Describe how to deal with options that follow non-option ARGV-elements.
 
@@ -200,11 +193,7 @@ static char *posixly_correct;
 # define my_index	strchr
 #else
 
-# if HAVE_STRING_H
-#  include <string.h>
-# else
-#  include <strings.h>
-# endif
+#include <string.h>
 
 /* Avoid depending on library functions or files
    whose names are inconsistent.  */
@@ -309,7 +298,7 @@ exchange (argv)
 {
   int bottom = first_nonopt;
   int middle = last_nonopt;
-  int top = optind;
+  int top = gg_optind;
   char *tem;
 
   /* Exchange the shorter segment with the far end of the longer segment.
@@ -379,8 +368,8 @@ exchange (argv)
 
   /* Update records for the slots the non-options now occupy.  */
 
-  first_nonopt += (optind - last_nonopt);
-  last_nonopt = optind;
+  first_nonopt += (gg_optind - last_nonopt);
+  last_nonopt = gg_optind;
 }
 
 /* Initialize the internal data when the first call is made.  */
@@ -398,7 +387,7 @@ _getopt_initialize (argc, argv, optstring)
      is the program name); the sequence of previously skipped
      non-option ARGV-elements is empty.  */
 
-  first_nonopt = last_nonopt = optind;
+  first_nonopt = last_nonopt = gg_optind;
 
   nextchar = NULL;
 
@@ -521,10 +510,10 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 {
   optarg = NULL;
 
-  if (optind == 0 || !__getopt_initialized)
+  if (gg_optind == 0 || !__getopt_initialized)
     {
-      if (optind == 0)
-	optind = 1;	/* Don't scan ARGV[0], the program name.  */
+      if (gg_optind == 0)
+	gg_optind = 1;	/* Don't scan ARGV[0], the program name.  */
       optstring = _getopt_initialize (argc, argv, optstring);
       __getopt_initialized = 1;
     }
@@ -534,11 +523,11 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
      from the shell indicating it is not an option.  The later information
      is only used when the used in the GNU libc.  */
 #ifdef _LIBC
-# define NONOPTION_P (argv[optind][0] != '-' || argv[optind][1] == '\0'	      \
-		      || (optind < nonoption_flags_len			      \
-			  && __getopt_nonoption_flags[optind] == '1'))
+# define NONOPTION_P (argv[gg_optind][0] != '-' || argv[gg_optind][1] == '\0'	      \
+		      || (gg_optind < nonoption_flags_len			      \
+			  && __getopt_nonoption_flags[gg_optind] == '1'))
 #else
-# define NONOPTION_P (argv[optind][0] != '-' || argv[optind][1] == '\0')
+# define NONOPTION_P (argv[gg_optind][0] != '-' || argv[gg_optind][1] == '\0')
 #endif
 
   if (nextchar == NULL || *nextchar == '\0')
@@ -547,27 +536,27 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 
       /* Give FIRST_NONOPT & LAST_NONOPT rational values if OPTIND has been
 	 moved back by the user (who may also have changed the arguments).  */
-      if (last_nonopt > optind)
-	last_nonopt = optind;
-      if (first_nonopt > optind)
-	first_nonopt = optind;
+      if (last_nonopt > gg_optind)
+	last_nonopt = gg_optind;
+      if (first_nonopt > gg_optind)
+	first_nonopt = gg_optind;
 
       if (ordering == PERMUTE)
 	{
 	  /* If we have just processed some options following some non-options,
 	     exchange them so that the options come first.  */
 
-	  if (first_nonopt != last_nonopt && last_nonopt != optind)
+	  if (first_nonopt != last_nonopt && last_nonopt != gg_optind)
 	    exchange ((char **) argv);
-	  else if (last_nonopt != optind)
-	    first_nonopt = optind;
+	  else if (last_nonopt != gg_optind)
+	    first_nonopt = gg_optind;
 
 	  /* Skip any additional non-options
 	     and extend the range of non-options previously skipped.  */
 
-	  while (optind < argc && NONOPTION_P)
-	    optind++;
-	  last_nonopt = optind;
+	  while (gg_optind < argc && NONOPTION_P)
+	    gg_optind++;
+	  last_nonopt = gg_optind;
 	}
 
       /* The special ARGV-element `--' means premature end of options.
@@ -575,28 +564,28 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 	 then exchange with previous non-options as if it were an option,
 	 then skip everything else like a non-option.  */
 
-      if (optind != argc && !strcmp (argv[optind], "--"))
+      if (gg_optind != argc && !strcmp (argv[gg_optind], "--"))
 	{
-	  optind++;
+	  gg_optind++;
 
-	  if (first_nonopt != last_nonopt && last_nonopt != optind)
+	  if (first_nonopt != last_nonopt && last_nonopt != gg_optind)
 	    exchange ((char **) argv);
 	  else if (first_nonopt == last_nonopt)
-	    first_nonopt = optind;
+	    first_nonopt = gg_optind;
 	  last_nonopt = argc;
 
-	  optind = argc;
+	  gg_optind = argc;
 	}
 
       /* If we have done all the ARGV-elements, stop the scan
 	 and back over any non-options that we skipped and permuted.  */
 
-      if (optind == argc)
+      if (gg_optind == argc)
 	{
 	  /* Set the next-arg-index to point at the non-options
 	     that we previously skipped, so the caller will digest them.  */
 	  if (first_nonopt != last_nonopt)
-	    optind = first_nonopt;
+	    gg_optind = first_nonopt;
 	  return -1;
 	}
 
@@ -607,15 +596,15 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 	{
 	  if (ordering == REQUIRE_ORDER)
 	    return -1;
-	  optarg = argv[optind++];
+	  optarg = argv[gg_optind++];
 	  return 1;
 	}
 
       /* We have found another option-ARGV-element.
 	 Skip the initial punctuation.  */
 
-      nextchar = (argv[optind] + 1
-		  + (longopts != NULL && argv[optind][1] == '-'));
+      nextchar = (argv[gg_optind] + 1
+		  + (longopts != NULL && argv[gg_optind][1] == '-'));
     }
 
   /* Decode the current option-ARGV-element.  */
@@ -634,8 +623,8 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
      This distinction seems to be the most useful approach.  */
 
   if (longopts != NULL
-      && (argv[optind][1] == '-'
-	  || (long_only && (argv[optind][2] || !my_index (optstring, argv[optind][1])))))
+      && (argv[gg_optind][1] == '-'
+	  || (long_only && (argv[gg_optind][2] || !my_index (optstring, argv[gg_optind][1])))))
     {
       char *nameend;
       const struct option *p;
@@ -675,19 +664,19 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 
       if (ambig && !exact)
 	{
-	  if (opterr)
+	  if (gg_opterr)
 	    fprintf (stderr, _("%s: option `%s' is ambiguous\n"),
-		     argv[0], argv[optind]);
+		     argv[0], argv[gg_optind]);
 	  nextchar += strlen (nextchar);
-	  optind++;
-	  optopt = 0;
+	  gg_optind++;
+	  gg_optopt = 0;
 	  return '?';
 	}
 
       if (pfound != NULL)
 	{
 	  option_index = indfound;
-	  optind++;
+	  gg_optind++;
 	  if (*nameend)
 	    {
 	      /* Don't test has_arg with >, because some C compilers don't
@@ -696,9 +685,9 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 		optarg = nameend + 1;
 	      else
 		{
-		  if (opterr)
+		  if (gg_opterr)
 		    {
-		      if (argv[optind - 1][1] == '-')
+		      if (argv[gg_optind - 1][1] == '-')
 			/* --option */
 			fprintf (stderr,
 				 _("%s: option `--%s' doesn't allow an argument\n"),
@@ -707,27 +696,27 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 			/* +option or -option */
 			fprintf (stderr,
 				 _("%s: option `%c%s' doesn't allow an argument\n"),
-				 argv[0], argv[optind - 1][0], pfound->name);
+				 argv[0], argv[gg_optind - 1][0], pfound->name);
 		    }
 
 		  nextchar += strlen (nextchar);
 
-		  optopt = pfound->val;
+		  gg_optopt = pfound->val;
 		  return '?';
 		}
 	    }
 	  else if (pfound->has_arg == 1)
 	    {
-	      if (optind < argc)
-		optarg = argv[optind++];
+	      if (gg_optind < argc)
+		optarg = argv[gg_optind++];
 	      else
 		{
-		  if (opterr)
+		  if (gg_opterr)
 		    fprintf (stderr,
 			   _("%s: option `%s' requires an argument\n"),
-			   argv[0], argv[optind - 1]);
+			   argv[0], argv[gg_optind - 1]);
 		  nextchar += strlen (nextchar);
-		  optopt = pfound->val;
+		  gg_optopt = pfound->val;
 		  return optstring[0] == ':' ? ':' : '?';
 		}
 	    }
@@ -746,23 +735,23 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 	 or the option starts with '--' or is not a valid short
 	 option, then it's an error.
 	 Otherwise interpret it as a short option.  */
-      if (!long_only || argv[optind][1] == '-'
+      if (!long_only || argv[gg_optind][1] == '-'
 	  || my_index (optstring, *nextchar) == NULL)
 	{
-	  if (opterr)
+	  if (gg_opterr)
 	    {
-	      if (argv[optind][1] == '-')
+	      if (argv[gg_optind][1] == '-')
 		/* --option */
 		fprintf (stderr, _("%s: unrecognized option `--%s'\n"),
 			 argv[0], nextchar);
 	      else
 		/* +option or -option */
 		fprintf (stderr, _("%s: unrecognized option `%c%s'\n"),
-			 argv[0], argv[optind][0], nextchar);
+			 argv[0], argv[gg_optind][0], nextchar);
 	    }
 	  nextchar = (char *) "";
-	  optind++;
-	  optopt = 0;
+	  gg_optind++;
+	  gg_optopt = 0;
 	  return '?';
 	}
     }
@@ -775,11 +764,11 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 
     /* Increment `optind' when we start to process its last character.  */
     if (*nextchar == '\0')
-      ++optind;
+      ++gg_optind;
 
     if (temp == NULL || c == ':')
       {
-	if (opterr)
+	if (gg_opterr)
 	  {
 	    if (posixly_correct)
 	      /* 1003.2 specifies the format of this message.  */
@@ -789,7 +778,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 	      fprintf (stderr, _("%s: invalid option -- %c\n"),
 		       argv[0], c);
 	  }
-	optopt = c;
+	gg_optopt = c;
 	return '?';
       }
     /* Convenience. Treat POSIX -W foo same as long option --foo */
@@ -809,17 +798,17 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 	    optarg = nextchar;
 	    /* If we end this ARGV-element by taking the rest as an arg,
 	       we must advance to the next element now.  */
-	    optind++;
+	    gg_optind++;
 	  }
-	else if (optind == argc)
+	else if (gg_optind == argc)
 	  {
-	    if (opterr)
+	    if (gg_opterr)
 	      {
 		/* 1003.2 specifies the format of this message.  */
 		fprintf (stderr, _("%s: option requires an argument -- %c\n"),
 			 argv[0], c);
 	      }
-	    optopt = c;
+	    gg_optopt = c;
 	    if (optstring[0] == ':')
 	      c = ':';
 	    else
@@ -829,7 +818,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 	else
 	  /* We already incremented `optind' once;
 	     increment it again when taking next ARGV-elt as argument.  */
-	  optarg = argv[optind++];
+	  optarg = argv[gg_optind++];
 
 	/* optarg is now the argument, see if it's in the
 	   table of longopts.  */
@@ -862,11 +851,11 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 	    }
 	if (ambig && !exact)
 	  {
-	    if (opterr)
+	    if (gg_opterr)
 	      fprintf (stderr, _("%s: option `-W %s' is ambiguous\n"),
-		       argv[0], argv[optind]);
+		       argv[0], argv[gg_optind]);
 	    nextchar += strlen (nextchar);
-	    optind++;
+	    gg_optind++;
 	    return '?';
 	  }
 	if (pfound != NULL)
@@ -880,7 +869,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 		  optarg = nameend + 1;
 		else
 		  {
-		    if (opterr)
+		    if (gg_opterr)
 		      fprintf (stderr, _("\
 %s: option `-W %s' doesn't allow an argument\n"),
 			       argv[0], pfound->name);
@@ -891,14 +880,14 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 	      }
 	    else if (pfound->has_arg == 1)
 	      {
-		if (optind < argc)
-		  optarg = argv[optind++];
+		if (gg_optind < argc)
+		  optarg = argv[gg_optind++];
 		else
 		  {
-		    if (opterr)
+		    if (gg_opterr)
 		      fprintf (stderr,
 			       _("%s: option `%s' requires an argument\n"),
-			       argv[0], argv[optind - 1]);
+			       argv[0], argv[gg_optind - 1]);
 		    nextchar += strlen (nextchar);
 		    return optstring[0] == ':' ? ':' : '?';
 		  }
@@ -924,7 +913,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 	    if (*nextchar != '\0')
 	      {
 		optarg = nextchar;
-		optind++;
+		gg_optind++;
 	      }
 	    else
 	      optarg = NULL;
@@ -938,18 +927,18 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 		optarg = nextchar;
 		/* If we end this ARGV-element by taking the rest as an arg,
 		   we must advance to the next element now.  */
-		optind++;
+		gg_optind++;
 	      }
-	    else if (optind == argc)
+	    else if (gg_optind == argc)
 	      {
-		if (opterr)
+		if (gg_opterr)
 		  {
 		    /* 1003.2 specifies the format of this message.  */
 		    fprintf (stderr,
 			   _("%s: option requires an argument -- %c\n"),
 			   argv[0], c);
 		  }
-		optopt = c;
+		gg_optopt = c;
 		if (optstring[0] == ':')
 		  c = ':';
 		else
@@ -958,7 +947,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 	    else
 	      /* We already incremented `optind' once;
 		 increment it again when taking next ARGV-elt as argument.  */
-	      optarg = argv[optind++];
+	      optarg = argv[gg_optind++];
 	    nextchar = NULL;
 	  }
       }
@@ -967,7 +956,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 }
 
 int
-getopt (argc, argv, optstring)
+gg_getopt (argc, argv, optstring)
      int argc;
      char *const *argv;
      const char *optstring;
@@ -995,9 +984,9 @@ main (argc, argv)
 
   while (1)
     {
-      int this_option_optind = optind ? optind : 1;
+      int this_option_optind = gg_optind ? gg_optind : 1;
 
-      c = getopt (argc, argv, "abc:d:0123456789");
+      c = gg_getopt (argc, argv, "abc:d:0123456789");
       if (c == -1)
 	break;
 
@@ -1039,11 +1028,11 @@ main (argc, argv)
 	}
     }
 
-  if (optind < argc)
+  if (gg_optind < argc)
     {
       printf ("non-option ARGV-elements: ");
-      while (optind < argc)
-	printf ("%s ", argv[optind++]);
+      while (gg_optind < argc)
+	printf ("%s ", argv[gg_optind++]);
       printf ("\n");
     }
 
